@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoCutIn.cpp,v 1.4 2009/01/04 00:26:03 bowkenken Exp $
+* $Id: DemoCutIn.cpp,v 1.5 2009/08/09 01:43:21 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -99,7 +99,7 @@ void DemoCutIn::init( WSCstring dirName )
 	// åȥ
 
 	if( nFileMaxN > 0 )
-		nFileSelN = randm( nFileMaxN );
+		nFileSelN = gui_randm( nFileMaxN );
 	else
 		nFileSelN = -1;
 
