@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiInputString.cpp,v 1.23 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiInputString.cpp,v 1.24 2009/07/31 12:10:26 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -132,12 +132,11 @@ void GuiInputString::newWin()
 
 	// ȥ
 
-	mTitle = gtk_entry_new();
+	mTitle = gtk_label_new( "" );
 	if( mTitle == NULL ){
-		print_msg( FLG_MSG_ERR, "gtk_entry_new()" );
+		print_msg( FLG_MSG_ERR, "gtk_label_new()" );
 		return;
 	}
-	gtk_entry_set_editable( GTK_ENTRY( mTitle ), FALSE );
 	gtk_box_pack_start( GTK_BOX( pBox ), mTitle,
 			FALSE, TRUE, 0 );
 	gtk_widget_show( mTitle );
@@ -153,6 +152,14 @@ void GuiInputString::newWin()
 			FALSE, TRUE, 0 );
 	gtk_widget_show( mEntry );
 
+	// ȥ꡼ؤΥ٥ȡϥɥ
+
+	gtk_signal_connect( GTK_OBJECT( mEntry ),
+			"activate",
+			GTK_SIGNAL_FUNC(
+			handle_input_string_ok_clicked ),
+			this );
+
 	// 󥻥롦ܥ
 
 	GtkWidget *pBoxButton = gtk_hbox_new( FALSE, 0 );
@@ -186,8 +193,16 @@ void GuiInputString::newWin()
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
 		return;
 	}
+
+	// ǥեȡܥ
+	GTK_WIDGET_SET_FLAGS( mOkButton, GTK_CAN_DEFAULT );
+
 	gtk_box_pack_start( GTK_BOX( pBoxButton ), mOkButton,
 			FALSE, FALSE, 0 );
+
+	// ǥեȡܥ
+	gtk_widget_grab_default( mOkButton );
+
 	gtk_widget_show( mOkButton );
 
 	// OK ܥؤΥ٥ȡϥɥ
@@ -254,17 +269,17 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 	if( mWin == NULL )
 		return;
 
-	GtkEntry *t;
+	GtkLabel *t;
 	GtkWindow *w;
 
-	t = GTK_ENTRY( gGuiInpStr.mTitle );
+	t = GTK_LABEL( gGuiInpStr.mTitle );
 	w = GTK_WINDOW( gGuiInpStr.mWin );
 	if( ttl == NULL ){
 		gtk_window_set_title( w, "" );
-		gtk_entry_set_text( t, "" );
+		gtk_label_set_text( t, "" );
 	} else {
 		gtk_window_set_title( w, ttl );
-		gtk_entry_set_text( t, ttl );
+		gtk_label_set_text( t, ttl );
 	}
 
 	GtkEntry *e;
@@ -276,6 +291,8 @@ void GuiInputString::draw( const char *ttl, const char *str, long len )
 		gtk_entry_set_text( e, str );
 	}
 
+	gtk_widget_grab_focus( gGuiInpStr.mEntry );
+
 	gWinPos[WIN_KIND_INPUT_STRING].draw( WIN_KIND_INPUT_STRING );
 #endif // D_GTK
 
