@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: Key.cpp,v 1.23 2009/07/04 08:17:15 bowkenken Exp $
+* $Id: Key.cpp,v 1.25 2009/08/15 04:46:06 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -157,49 +157,49 @@ static WSCbool handler( long keyCode, WSCbool flagOn )
 		break;
 	// ե󥯥󡦥
 	case WSK_F1:
-		key = KEY_F( 1 );
+		key = KEY_LNL_FUNC( 1 );
 		break;
 	case WSK_F2:
-		key = KEY_F( 2 );
+		key = KEY_LNL_FUNC( 2 );
 		break;
 	case WSK_F3:
-		key = KEY_F( 3 );
+		key = KEY_LNL_FUNC( 3 );
 		break;
 	case WSK_F4:
-		key = KEY_F( 4 );
+		key = KEY_LNL_FUNC( 4 );
 		break;
 	case WSK_F5:
-		key = KEY_F( 5 );
+		key = KEY_LNL_FUNC( 5 );
 		break;
 	case WSK_F6:
-		key = KEY_F( 6 );
+		key = KEY_LNL_FUNC( 6 );
 		break;
 	case WSK_F7:
-		key = KEY_F( 7 );
+		key = KEY_LNL_FUNC( 7 );
 		break;
 	case WSK_F8:
-		key = KEY_F( 8 );
+		key = KEY_LNL_FUNC( 8 );
 		break;
 	case WSK_F9:
-		key = KEY_F( 9 );
+		key = KEY_LNL_FUNC( 9 );
 		break;
 	case WSK_F10:
-		key = KEY_F( 10 );
+		key = KEY_LNL_FUNC( 10 );
 		break;
 	case WSK_F11:
-		key = KEY_F( 11 );
+		key = KEY_LNL_FUNC( 11 );
 		break;
 	case WSK_F12:
-		key = KEY_F( 12 );
+		key = KEY_LNL_FUNC( 12 );
 		break;
 	case WSK_F13:
-		key = KEY_F( 13 );
+		key = KEY_LNL_FUNC( 13 );
 		break;
 	case WSK_F14:
-		key = KEY_F( 14 );
+		key = KEY_LNL_FUNC( 14 );
 		break;
 	case WSK_F15:
-		key = KEY_F( 15 );
+		key = KEY_LNL_FUNC( 15 );
 		break;
 	// ¾
 	case WSK_bracketleft:
@@ -441,7 +441,7 @@ gboolean handleKeyPress(
 	case GDK_F34:
 	case GDK_F35:
 		char buf[15 + 1];
-		sprintf( buf, "&%2ld", key - GDK_F1 + 1 );
+		sprintf( buf, "&f%ld;", key - GDK_F1 );
 		gKey.setString( buf, true, true );
 
 		return 1;
@@ -611,8 +611,8 @@ void Key::handleKeyDown(
 	case VK_F23:
 	case VK_F24:
 		char buf[15 + 1];
-		sprintf( buf, "&%2ld", key - VK_F1 + 1 );
-		setString( buf, true );
+		sprintf( buf, "&%02ld", key - VK_F1 + 1 );
+		setString( buf, true, true );
 
 		return;
 	}
@@ -730,11 +730,11 @@ void Key::setStringKeyTab( WSCstring s, bool flagMacro )
 
 		if( c <= '\0' )
 			bFlgTab = false;
-		if( c >= KEY_TAB_MAX_N )
+		else if( c >= KEY_TAB_MAX_N )
 			bFlgTab = false;
-		if( tab[c] == NULL )
+		else if( tab[c] == NULL )
 			bFlgTab = false;
-		if( !flagMacro )
+		else if( !flagMacro )
 			bFlgTab = false;
 
 		if( bFlgTab ){
