@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: WinPos.cpp,v 1.18 2009/07/11 13:57:28 bowkenken Exp $
+* $Id: WinPos.cpp,v 1.19 2009/08/15 04:46:06 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -33,6 +33,7 @@
 ////////////////////////////////////////////////////////////////
 
 #include "gmain.h"
+#include "gmain-prot.h"
 
 #include "WinPos.h"
 #include "GlobalVar.h"
@@ -67,7 +68,6 @@ WinPos::~WinPos()
 void *WinPos::getWin( win_kind_t kind )
 {
 #ifdef D_WS
-//@@@
 #endif // D_WS
 
 #ifdef D_GTK
@@ -220,7 +220,6 @@ void WinPos::calc( win_kind_t kind )
 		return;
 
 #ifdef D_WS
-//@@@
 #endif // D_WS
 
 #ifdef D_GTK
@@ -275,6 +274,9 @@ void WinPos::calc( win_kind_t kind )
 
 void WinPos::draw( win_kind_t kind, bool flagDlg )
 {
+	if( flagDraw )
+		return;
+
 	void *pWin = getWin( kind );
 	if( pWin == NULL )
 		return;
@@ -287,8 +289,12 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 	gtk_widget_show( GTK_WIDGET( pWin ) );
 
 	if( g_flg_set_win_pos ){
-		gdk_window_move( GTK_WIDGET( pWin )->window, mX, mY );
-		gdk_window_resize( GTK_WIDGET( pWin )->window, mW, mH );
+		if( (mW > 0) && (mH > 0) ){
+			gdk_window_move( GTK_WIDGET( pWin )->window,
+					mX, mY );
+			gdk_window_resize( GTK_WIDGET( pWin )->window,
+					mW, mH );
+		}
 	}
 
 	gdk_window_raise( GTK_WIDGET( pWin )->window );
@@ -331,7 +337,8 @@ void WinPos::draw( win_kind_t kind, bool flagDlg )
 
 void WinPos::wipe( win_kind_t kind, bool flagDlg )
 {
-	flagDraw = false;
+	if( !flagDraw )
+		return;
 
 	void *pWin = getWin( kind );
 	if( pWin == NULL )
@@ -340,7 +347,6 @@ void WinPos::wipe( win_kind_t kind, bool flagDlg )
 	calc( kind );
 
 #ifdef D_WS
-//@@@
 	pWin->setVisible( false );
 #endif // D_WS
 
@@ -352,4 +358,6 @@ void WinPos::wipe( win_kind_t kind, bool flagDlg )
 	if( !flagDlg )
 		((CWnd *)pWin)->ShowWindow( SW_HIDE );
 #endif //D_MFC
+
+	flagDraw = false;
 }
