@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.c,v 1.86 2009/05/12 01:47:00 bowkenken Exp $
+* $Id: amenu.c,v 1.93 2009/08/09 07:37:02 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -43,23 +43,32 @@
 /***************************************************************/
 
 static auto_mark_t	ls_auto_mark[LS_MBR_MAX_N][AUTO_MARK_MAX_N];
+check_memory_def( check_memory_amenu_c_ls_auto_mark )
 static bool_t	ls_flg_ena_auto_mark[AUTO_MARK_MAX_N];
+check_memory_def( check_memory_amenu_c_ls_flg_ena_auto_mark )
 
 static auto_mark_t	clip_board_large[LS_MBR_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_large )
 static auto_mark_t	clip_board_small;
+check_memory_def( check_memory_amenu_c_clip_board_small )
 
 static auto_mark_appoint_item_t	clip_board_large_item
 		[LS_MBR_MAX_N][AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_large_item )
 static auto_mark_appoint_item_t	clip_board_small_item
 		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_clip_board_small_item )
 
 static char	msg_ttl_auto_mark[AUTO_MARK_MAX_N]
-		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+check_memory_def( check_memory_amenu_c_msg_ttl_auto_mark )
 static char	clip_board_ttl
-		[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+		[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+check_memory_def( check_memory_amenu_c_clip_board_ttl )
 
 static long	auto_mark_cur_n;
 static mbr_t	*g_sel_mbr;
+check_memory_def( check_memory_amenu_c_auto_mark_cur_n )
 
 static auto_mark_t	dflt_auto_mark_fight = {
 	AUTO_MARK_TRGT_MNSTR,
@@ -121,7 +130,7 @@ static auto_mark_t	dflt_auto_mark_fight_all = {
 	AUTO_MARK_ACT_FIGHT,
 	AUTO_MARK_COND_DISPERSE,
 	"",
-	FLG_NULL,
+	FLG_AUTO_MARK_EDIT_CONT,
 };
 
 static auto_mark_t	dflt_auto_mark_fight_all_prio = {
@@ -160,9 +169,12 @@ static auto_mark_t	dflt_auto_mark_clear = {
 	FLG_AUTO_MARK_EDIT_PRIORITY,
 };
 
+check_memory_def( check_memory_amenu_c_dflt_auto_mark_fight )
+
 static auto_mark_appoint_item_t	auto_mark_appoint_item
 		[LS_MBR_MAX_N][AUTO_MARK_MAX_N]
 		[AUTO_MARK_APPOINT_ITEM_MAX_N];
+check_memory_def( check_memory_amenu_c_auto_mark_appoint_item )
 
 static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 		[AUTO_MARK_APPOINT_ITEM_MAX_N] = {
@@ -225,6 +237,7 @@ static auto_mark_appoint_item_t	auto_mark_appoint_item_dflt
 
 	{ FACE_MJR_NULL, FACE_MNR_NULL, FALSE },
 };
+check_memory_def( check_memory_amenu_c_auto_mark_appoint_item_dflt )
 
 /***************************************************************/
 
@@ -257,7 +270,7 @@ void	init_auto_menu( void )
 	clip_board_small = ls_auto_mark[0][0];
 	str_nz_cpy( clip_board_ttl,
 			msg_ttl_auto_mark[0],
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -275,7 +288,7 @@ void	reset_static_auto_menu( void )
 		clip_board_large[i] = dflt_auto_mark_fight;
 	clip_board_small = dflt_auto_mark_fight;
 	str_nz_cpy( clip_board_ttl, "",
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -349,7 +362,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = FALSE;
 	}
 
@@ -374,7 +387,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -397,7 +410,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_PRIO,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -418,7 +431,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -439,7 +452,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 	}
 	str_nz_cpy( msg_ttl_auto_mark[j],
 			MSG_NAME_DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	ls_flg_ena_auto_mark[j] = TRUE;
 	j++;
 
@@ -449,7 +462,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -460,7 +473,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -471,7 +484,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_RETREAT,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -482,7 +495,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_clear;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_CLEAR,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -493,7 +506,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -504,7 +517,7 @@ void	init_auto_mark_mbr( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_item_own;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_ITEM_OWN,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 		ls_flg_ena_auto_mark[j] = TRUE;
 	}
 	j++;
@@ -552,7 +565,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	j++;
 
@@ -569,7 +582,7 @@ void	ver_up_auto_mark_1_0_4( long ls_mbr_n )
 		ls_auto_mark[ls_mbr_n][j] = dflt_auto_mark_fight_all_prio;
 		str_nz_cpy( msg_ttl_auto_mark[j],
 				MSG_NAME_DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	j++;
 
@@ -661,13 +674,13 @@ void	ver_up_auto_mark_1_1_3( void )
 void	cv_msg_ttl_auto_mark( char *ttl )
 {
 	const char	old_split[] = " - ";
-	char	work_left[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
-	char	work_right[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	work_left[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
+	char	work_right[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 	char	*p;
 
 	/* ȥ뤫 " - " κ¦Ф */
 
-	str_nz_cpy( work_left, ttl, MSG_TTL_AUTO_MARK_MAX_LEN );
+	str_nz_cpy( work_left, ttl, MSG_TTL_AUTO_MARK_MAX_BYTE );
 	p = strstr( work_left, old_split );
 	if( p != NULL )
 		*p = '\0';
@@ -683,18 +696,19 @@ void	cv_msg_ttl_auto_mark( char *ttl )
 		long	len;
 
 		len = str_len_std( old_split );
-		str_nz_cpy( work_right, &(p[len]), MSG_TTL_AUTO_MARK_MAX_LEN );
+		str_nz_cpy( work_right, &(p[len]),
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	/* ȥ˽᤹ */
 
 	ttl[0] = '\0';
 	str_max_n_cat( ttl, work_left,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( ttl, work_right,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 }
 
 /***************************************************************
@@ -724,7 +738,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 {
 	long	left_max_len;
 	menu_t	*p;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16 + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 	char	key;
 	long	i, k;
 
@@ -747,7 +761,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 	p[k].accel_key = '\0';
 	p[k].short_key[0] = '\0';
 	str_nz_cpy( p[k].msg, MSG_TTL_MENU_AUTO_MARK,
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	p[k].call_back = NULL;
 	p[k].arg = NULL;
 	p[k].flg = FLG_NULL;
@@ -789,14 +803,14 @@ void	set_menu_auto_mark( menu_t **dflt )
 		kk = k;
 
 		if( ls_flg_ena_auto_mark[i] ){
-			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
 					(int)left_max_len,
 					get_msg_ttl_auto_mark_info( i ),
 					STR_TTL_AUTO_MARK_SPLIT_NAME,
 					get_msg_ttl_auto_mark_hint( i ) );
 		} else {
-			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_LEN * 3 + 16,
+			sn_printf( buf, MSG_TTL_AUTO_MARK_MAX_BYTE,
 					"%*s%s%s",
 					(int)left_max_len,
 					MSG_MENU_AUTO_MARK_NULL,
@@ -809,7 +823,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		str_nz_cpy( p[k].kind, "<Branch>", MENU_KIND_MAX_LEN );
 		p[k].accel_key = key;
 		p[k].short_key[0] = '\0';
-		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_LEN );
+		str_nz_cpy( p[k].msg, buf, MENU_MSG_MAX_BYTE );
 		p[k].call_back = NULL;
 		p[k].arg = NULL;
 		p[k].flg = FLG_NULL;
@@ -822,7 +836,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'X';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EXEC,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_exec;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -834,7 +848,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'E';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_edit;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -846,7 +860,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'N';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_EDIT_NAME,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_edit_name;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -858,7 +872,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'W';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_COPY,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_copy_large;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -870,7 +884,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'Y';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_PASTE,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_paste_large;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -882,7 +896,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'R';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_REMOVE,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_remove;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -894,7 +908,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'U';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_UP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_up;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -906,7 +920,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'D';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_DOWN,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_down;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -918,7 +932,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'T';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_TOP,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_top;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -930,7 +944,7 @@ void	set_menu_auto_mark( menu_t **dflt )
 		p[k].accel_key = 'B';
 		p[k].short_key[0] = '\0';
 		str_nz_cpy( p[k].msg, MSG_MENU_AUTO_MARK_ARRANGE_BOTTOM,
-				MENU_MSG_MAX_LEN );
+				MENU_MSG_MAX_BYTE );
 		p[k].call_back = cb_menu_auto_mark_arrange_bottom;
 		p[k].arg = (void *)i;
 		p[k].flg = FLG_NULL;
@@ -1071,6 +1085,7 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 
 	if( mbr == NULL )
 		return FALSE;
+
 	am = &(ls_auto_mark[mbr->ls_mbr_n][auto_mark_cur_n]);
 
 	switch( am->act ){
@@ -1147,12 +1162,14 @@ bool_t	exec_menu_auto_mark_mnstr( mbr_t *mbr )
 
 	/* 򥻥å */
 	set_chr_act( mbr, act_kind, NULL, NULL, 0, 0 );
-
 	/* 󥹥ޡ */
 	mark_mnstr( mbr, mnstr, dist );
 
 	draw_mbr_stat( mbr );
 
+	set_flg_mbr_find_mnstr( TRUE );
+	call_game_sound_play( SOUND_KIND_FIGHT_FIND_MEMBER, 1 );
+
 	return TRUE;
 }
 
@@ -1614,7 +1631,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_EDIT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1623,7 +1640,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "target" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_TRGT,
 			get_msg_menu_auto_mark_edit_trgt( g_sel_mbr ) );
 
@@ -1631,7 +1648,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "dist" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_DIST,
 			get_msg_menu_auto_mark_edit_dist( g_sel_mbr ) );
 
@@ -1639,7 +1656,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "action" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_ACT,
 			get_msg_menu_auto_mark_edit_act( g_sel_mbr ) );
 
@@ -1647,7 +1664,7 @@ char	*cb_menu_auto_mark_edit_init(
 	p = srch_menu( *pp, "condition" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_MENU_AUTO_MARK_EDIT_COND,
 			get_msg_menu_auto_mark_edit_cond( g_sel_mbr ) );
 
@@ -1697,7 +1714,7 @@ char	*cb_menu_auto_mark_trgt_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_TRGT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1801,7 +1818,7 @@ char	*cb_menu_auto_mark_dist_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_DIST,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -1865,7 +1882,7 @@ char	*cb_menu_auto_mark_act_init( menu_t **pp, menu_t **dflt )
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_ACT,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2015,7 +2032,7 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2116,7 +2133,7 @@ char	*cb_menu_auto_mark_cond_init(
 	p = srch_menu( *pp, "title" );
 	if( p == NULL )
 		return STR_MENU_ERR;
-	sn_printf( p->msg, MENU_MSG_MAX_LEN,
+	sn_printf( p->msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_COND,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2183,7 +2200,7 @@ char	*cb_menu_auto_mark_appoint_item(
 	ls[k].accel_key = '\0';
 	ls[k].short_key[0] = '\0';
 	ls[k].n_msg = N_MSG_NULL;
-	sn_printf( ls[k].msg, MENU_MSG_MAX_LEN,
+	sn_printf( ls[k].msg, MENU_MSG_MAX_BYTE,
 			MSG_TTL_MENU_AUTO_MARK_APPOINT_ITEM_MJR,
 			get_msg_ttl_auto_mark_info( auto_mark_cur_n ),
 			g_sel_mbr->name );
@@ -2242,7 +2259,7 @@ char	*set_menu_auto_mark_appoint_item(
 	ls[*k].short_key[0] = '\0';
 	ls[*k].n_msg = N_MSG_NULL;
 	str_nz_cpy( ls[*k].msg, get_item_mjr_name( mjr ),
-			MENU_MSG_MAX_LEN );
+			MENU_MSG_MAX_BYTE );
 	ls[*k].call_back = cb_menu_auto_mark_appoint_item_init;
 	ls[*k].arg = (void *)(*apo);
 	ls[*k].flg = FLG_NULL;
@@ -2269,7 +2286,7 @@ char	*set_menu_auto_mark_appoint_item(
 		ls[*k].accel_key = mnr_key;
 		ls[*k].short_key[0] = '\0';
 		ls[*k].n_msg = N_MSG_NULL;
-		str_nz_cpy( ls[*k].msg, name, MENU_MSG_MAX_LEN );
+		str_nz_cpy( ls[*k].msg, name, MENU_MSG_MAX_BYTE );
 		ls[*k].call_back = cb_menu_auto_mark_appoint_item_mnr;
 		ls[*k].arg = (void *)(*apo);
 		ls[*k].flg = FLG_NULL;
@@ -2365,10 +2382,10 @@ char	*cb_menu_auto_mark_edit_macro_bind( menu_t **pp, menu_t **dflt )
 	/* ޥ桼 */
 
 	x = str_len_draw( msg_cmd );
-	y = get_max_line() - 1;
+	y = get_screen_row() - 1;
 	str_nz_cpy( buf_cmd, cmd, MACRO_MAX_LEN );
 
-	if( game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, TRUE ) ){
+	if( game_gets( x, y, msg_cmd, buf_cmd, MACRO_MAX_LEN, FALSE ) ){
 		long	len;
 
 		/* βԤ */
@@ -2503,7 +2520,7 @@ char	*cb_menu_auto_mark_copy_large( menu_t **pp, menu_t **dflt )
 
 		str_nz_cpy( clip_board_ttl,
 				msg_ttl_auto_mark[n],
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	print_msg( FLG_NULL, MSG_MENU_AUTO_MARK_DONE_COPY );
@@ -2535,7 +2552,7 @@ char	*cb_menu_auto_mark_paste_large( menu_t **pp, menu_t **dflt )
 
 		str_nz_cpy( msg_ttl_auto_mark[n],
 				clip_board_ttl,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 	ls_flg_ena_auto_mark[n] = TRUE;
 
@@ -2610,15 +2627,15 @@ char	*cb_menu_auto_mark_paste_small( menu_t **pp, menu_t **dflt )
 char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 {
 	long	n;
-	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
-	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
+	static char	info[MSG_TTL_AUTO_MARK_INFO_MAX_BYTE + 1];
+	static char	hint[MSG_TTL_AUTO_MARK_HINT_MAX_BYTE + 1];
 
 	n = (long)((*pp)->arg);
 
 	str_nz_cpy( info, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
+			MSG_TTL_AUTO_MARK_INFO_MAX_BYTE );
 	str_nz_cpy( hint, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
+			MSG_TTL_AUTO_MARK_HINT_MAX_BYTE );
 
 	wipe_all();
 	gets_auto_mark_info( info );
@@ -2628,13 +2645,13 @@ char	*cb_menu_auto_mark_edit_name( menu_t **pp, menu_t **dflt )
 	msg_ttl_auto_mark[n][0] = '\0';
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			info,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			STR_TTL_AUTO_MARK_SPLIT_CODE,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( msg_ttl_auto_mark[n],
 			hint,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	return "/auto mark";
 }
@@ -2799,7 +2816,7 @@ bool_t	arrange_auto_mark_1( long n, long d )
 	auto_mark_t	am;
 	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	if( d == 0 )
 		return FALSE;
@@ -2838,14 +2855,14 @@ bool_t	arrange_auto_mark_1( long n, long d )
 	/**/
 
 	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	str_nz_cpy( get_msg_ttl_auto_mark_code( n ),
 			get_msg_ttl_auto_mark_code( n + d ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	str_nz_cpy( get_msg_ttl_auto_mark_code( n + d ), buf,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	/**/
 
@@ -2869,7 +2886,7 @@ bool_t	arrange_auto_mark( long n, long d )
 	auto_mark_appoint_item_t	item[AUTO_MARK_APPOINT_ITEM_MAX_N];
 	auto_mark_appoint_item_t	item_tmp;
 	const long	max_item = AUTO_MARK_APPOINT_ITEM_MAX_N;
-	char	buf[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	char	buf[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	if( d <= -1 )
 		d = -1;
@@ -2953,26 +2970,26 @@ bool_t	arrange_auto_mark( long n, long d )
 	/**/
 
 	str_nz_cpy( buf, get_msg_ttl_auto_mark_code( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	if( d <= -1 ){
 		for( j = n - 1; j >= 0; j-- ){
 			str_nz_cpy( get_msg_ttl_auto_mark_code( j + 1 ),
 					get_msg_ttl_auto_mark_code( j ),
-					MSG_TTL_AUTO_MARK_MAX_LEN );
+					MSG_TTL_AUTO_MARK_MAX_BYTE );
 		}
 
 		str_nz_cpy( get_msg_ttl_auto_mark_code( 0 ), buf,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	} else {
 		for( j = n + 1; j < AUTO_MARK_MAX_N; j++ ){
 			str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ),
 					get_msg_ttl_auto_mark_code( j ),
-					MSG_TTL_AUTO_MARK_MAX_LEN );
+					MSG_TTL_AUTO_MARK_MAX_BYTE );
 		}
 
 		str_nz_cpy( get_msg_ttl_auto_mark_code( j - 1 ), buf,
-				MSG_TTL_AUTO_MARK_MAX_LEN );
+				MSG_TTL_AUTO_MARK_MAX_BYTE );
 	}
 
 	/**/
@@ -3313,15 +3330,15 @@ char	*get_msg_ttl_auto_mark_code( long n )
 
 char	*get_msg_ttl_auto_mark_name( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_MAX_BYTE + 1];
 
 	str[0] = '\0';
 	str_max_n_cat( str, get_msg_ttl_auto_mark_info( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( str, STR_TTL_AUTO_MARK_SPLIT_NAME,
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 	str_max_n_cat( str, get_msg_ttl_auto_mark_hint( n ),
-			MSG_TTL_AUTO_MARK_MAX_LEN );
+			MSG_TTL_AUTO_MARK_MAX_BYTE );
 
 	return str;
 }
@@ -3334,22 +3351,22 @@ char	*get_msg_ttl_auto_mark_name( long n )
 
 char	*get_msg_ttl_auto_mark_info( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_INFO_MAX_BYTE + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
 
 	p = strstr( ttl, STR_TTL_AUTO_MARK_SPLIT_CODE );
 	if( p == NULL ){
-		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_LEN );
+		str_nz_cpy( str, ttl, MSG_TTL_AUTO_MARK_INFO_MAX_BYTE );
 	} else {
 		long	len;
 
 		len = p - ttl;
 		if( len < 0 )
 			len = 0;
-		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_LEN )
-			len = MSG_TTL_AUTO_MARK_INFO_MAX_LEN;
+		if( len > MSG_TTL_AUTO_MARK_INFO_MAX_BYTE )
+			len = MSG_TTL_AUTO_MARK_INFO_MAX_BYTE;
 
 		str_nz_cpy( str, ttl, len );
 	}
@@ -3365,7 +3382,7 @@ char	*get_msg_ttl_auto_mark_info( long n )
 
 char	*get_msg_ttl_auto_mark_hint( long n )
 {
-	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_LEN + 1];
+	static char	str[MSG_TTL_AUTO_MARK_HINT_MAX_BYTE + 1];
 	char	*ttl, *p;
 
 	ttl = msg_ttl_auto_mark[n];
@@ -3377,7 +3394,7 @@ char	*get_msg_ttl_auto_mark_hint( long n )
 		long	len;
 
 		len = str_len_std( STR_TTL_AUTO_MARK_SPLIT_CODE );
-		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_LEN );
+		str_nz_cpy( str, &(p[len]), MSG_TTL_AUTO_MARK_HINT_MAX_BYTE );
 	}
 
 	return str;
@@ -3453,3 +3470,35 @@ auto_mark_appoint_item_t	*get_ls_auto_mark_appoint_item(
 
 	return( auto_mark_appoint_item[ls_mbr_n][n] );
 }
+
+/***************************************************************
+* ꡼å
+***************************************************************/
+
+void	check_memory_amenu_c( void )
+{
+	check_memory( check_memory_amenu_c_ls_auto_mark,
+			"amenu.c: ls_auto_mark" );
+	check_memory( check_memory_amenu_c_ls_flg_ena_auto_mark,
+			"amenu.c: ls_flg_ena_auto_mark" );
+	check_memory( check_memory_amenu_c_clip_board_large,
+			"amenu.c: clip_board_large" );
+	check_memory( check_memory_amenu_c_clip_board_small,
+			"amenu.c: clip_board_small" );
+	check_memory( check_memory_amenu_c_clip_board_large_item,
+			"amenu.c: clip_board_large_item" );
+	check_memory( check_memory_amenu_c_clip_board_small_item,
+			"amenu.c: clip_board_small_item" );
+	check_memory( check_memory_amenu_c_msg_ttl_auto_mark,
+			"amenu.c: msg_ttl_auto_mark" );
+	check_memory( check_memory_amenu_c_clip_board_ttl,
+			"amenu.c: clip_board_ttl" );
+	check_memory( check_memory_amenu_c_auto_mark_cur_n,
+			"amenu.c: auto_mark_cur_n" );
+	check_memory( check_memory_amenu_c_dflt_auto_mark_fight,
+			"amenu.c: dflt_auto_mark_fight" );
+	check_memory( check_memory_amenu_c_auto_mark_appoint_item,
+			"amenu.c: auto_mark_appoint_item" );
+	check_memory( check_memory_amenu_c_auto_mark_appoint_item_dflt,
+			"amenu.c: auto_mark_appoint_item_dflt" );
+}
