@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.163 2009/07/13 07:01:42 bowkenken Exp $
+* $Id: fight.c,v 1.164 2009/07/30 12:16:15 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -1319,6 +1319,8 @@ bool_t	fight_x_1(
 	}
 
 	print_msg( FLG_NULL, get_msg_attack( attack ), o_name, d_name );
+	print_msg( FLG_NULL, MSG_FIGHT_RESI_KIND,
+			get_resi_name( attack->resi_kind ) );
 
 	bgn.x = o_p->x;
 	bgn.y = o_p->y;
@@ -1922,6 +1924,8 @@ bool_t	spell_attack(
 
 	/* ᡼ɽ */
 
+	print_msg( FLG_NULL, MSG_FIGHT_RESI_KIND, get_resi_name( resi ) );
+
 	curs_attrset_chr( d_p, -1, FALSE );
 	print_msg_find( d_p, FLG_NULL, MSG_FIGHT_HIT_STD, d_name, dam );
 	curs_attrset_dflt();
