@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.133 2009/06/27 14:47:20 bowkenken Exp $
+* $Id: gmain.c,v 1.135 2009/08/15 06:21:45 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -692,7 +692,7 @@ void	close_game( long code )
 	close_item();
 
 	if( !g_flg_use_curs )
-		curs_move( get_max_line() - 1, SCREEN_MIN_X );
+		curs_move( get_screen_row() - 1, SCREEN_MIN_X );
 
 	reset_scrn();
 	fflush( stdout );
@@ -733,7 +733,7 @@ void	about_game( bool_t flg_init )
 		return;
 	}
 
-	curs_move( WIN_MSG_DRAW_MIN_Y, SCREEN_MIN_X );
+	curs_move( get_map_row() + 1, SCREEN_MIN_X );
 
 	dis_scrn();
 
