@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.75 2009/06/26 16:58:16 bowkenken Exp $
+* $Id: last-boss.c,v 1.77 2009/08/09 07:37:02 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -813,6 +813,7 @@ void	draw_last_boss( void )
 	case LAST_SCENE_N_ENCOUNTER_CUT_OUT:
 		break;
 	case LAST_SCENE_N_ENCOUNTER_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -835,6 +836,7 @@ void	draw_last_boss( void )
 	case LAST_SCENE_N_EXEL_CUT_OUT:
 		break;
 	case LAST_SCENE_N_EXEL_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -876,6 +878,7 @@ void	draw_last_boss( void )
 	case LAST_SCENE_N_EXELER_CUT_OUT:
 		break;
 	case LAST_SCENE_N_EXELER_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -924,6 +927,7 @@ void	draw_last_boss( void )
 	case LAST_SCENE_N_XEX_CUT_OUT:
 		break;
 	case LAST_SCENE_N_XEX_CUT_END:
+		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		redraw_all();
 		wait_frame_gui( REDRAW_ALL_WAIT_FRAME_N );
 		break;
@@ -1761,10 +1765,10 @@ void	draw_xex_earthquake( pos_t *draw, pos_t base_draw )
 		x = 0;
 	if( y < 0 )
 		y = 0;
-	if( x > MAP_MAX_X - WIN_MAP_WIDTH )
-		x = MAP_MAX_X - WIN_MAP_WIDTH;
-	if( y > MAP_MAX_Y - WIN_MAP_HEIGHT )
-		y = MAP_MAX_Y - WIN_MAP_HEIGHT;
+	if( x > MAP_MAX_X - (get_map_col() / 2) )
+		x = MAP_MAX_X - (get_map_col() / 2);
+	if( y > MAP_MAX_Y - get_map_row() )
+		y = MAP_MAX_Y - get_map_row();
 
 	draw->x = x;
 	draw->y = y;
