@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: main-dows.cpp,v 1.34 2009/07/12 11:38:28 bowkenken Exp $
+* $Id: main-dows.cpp,v 1.35 2009/07/25 20:47:54 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -173,7 +173,11 @@ void	printMapStatBar( const char *s, ... )
 		return;
 
 	CStatusBar &bar = theApp.m_pMainFrm->GetStatusBar();
-	bar.SetPaneText( bar.CommandToIndex( ID_SEPARATOR ), str );
+	TRY {
+		if( g_flg_init )
+			bar.SetPaneText( bar.CommandToIndex( ID_SEPARATOR ), str );
+	} CATCH( CException, e ){
+	} END_CATCH
 }
 
 ////////////////////////////////////////////////////////////////
