@@ -58,6 +58,8 @@ void	handle_cancel_clicked(
 void	handle_ok_clicked(
 	GtkWidget *widget, gpointer *data
 );
+void	exec_cancel_clicked( void );
+void	exec_ok_clicked( void );
 gint	handle_map_button_press(
 	GtkWidget *widget, GdkEventMotion *event
 );
