@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: spell-tab.h,v 1.19 2009/07/12 17:27:30 bowkenken Exp $
+* $Id: spell-tab.h,v 1.21 2009/08/08 21:02:29 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	SPELL_TAB_H
@@ -163,26 +163,6 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
-	{
-		"/spell/MAG/dispel_magic",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_DISPEL_MAGIC, "",
-		cb_menu_spell, (void *)SPELL_KIND_DISPEL_MAGIC,
-		FLG_NULL,
-	},
-
-	{
-		"/spell/MAG/mirror_image",
-		"<Branch>",
-		'\0',
-		"",
-		N_MSG_SPELL_MIRROR_IMAGE, "",
-		cb_menu_spell, (void *)SPELL_KIND_MIRROR_IMAGE,
-		FLG_NULL,
-	},
-
 	{
 		"/spell/MAG/animate_objects",
 		"<Branch>",
@@ -423,6 +403,26 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/MAG/dispel_magic",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISPEL_MAGIC, "",
+		cb_menu_spell, (void *)SPELL_KIND_DISPEL_MAGIC,
+		FLG_NULL,
+	},
+
+	{
+		"/spell/MAG/mirror_image",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_MIRROR_IMAGE, "",
+		cb_menu_spell, (void *)SPELL_KIND_MIRROR_IMAGE,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/MAG/polymorph_other",
 		"<Branch>",
@@ -1942,6 +1942,16 @@ menu_t	ls_menu_spell[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/spell/SHA/dismissal_elemental",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_DISMISSAL_ELEMENTAL, "",
+		cb_menu_spell, (void *)SPELL_KIND_DISMISSAL_ELEMENTAL,
+		FLG_NULL,
+	},
+
 	{
 		"/spell/SHA/no_learn summon elemental",
 		"<Item>",
